#undef PACKAGE
#undef VERSION

#undef HAVE_MMAP
#undef HAVE_STRSEP
#undef HAVE_STRTOK_R
#undef HAVE_SIGACTION
#undef HAVE_WAITPID
#undef HAVE_LIBSM
#undef HAVE_LC_MESSAGES
#undef HAVE_STPCPY
#undef ENABLE_NLS
#undef HAVE_CATGETS
#undef HAVE_GETTEXT

#define DIFF_PATH  "/usr/bin/diff"
#define DIFF3_PATH  "/usr/bin/diff3"
